@@ -255,6 +255,26 @@ sub _default_patterns {
     $self->note($self->SIXTEENTH, $self->snare) for 0 .. 1;
     $self->note($self->EIGHTH, $self->strike(TOM3));
 },
+'7 fill' => sub {
+    my $self = shift;
+    $self->note($self->SIXTEENTH, $self->snare);
+    $self->note($self->EIGHTH, $self->snare);
+    $self->note($self->SIXTEENTH, $self->strike(TOM1));
+    $self->note($self->EIGHTH, $self->strike(TOM1));
+    $self->note($self->SIXTEENTH, $self->strike(TOM3)) for 0 .. 1;
+    $self->note($self->SIXTEENTH, $self->snare) for 0 .. 3;
+    $self->note($self->SIXTEENTH, $self->strike(TOM3)) for 0 .. 1;
+    $self->note($self->EIGHTH, $self->strike(TOM3));
+},
+'8 fill' => sub {
+    my $self = shift;
+    $self->note($self->EIGHTH, $self->snare);
+    $self->note($self->EIGHTH, $self->kick) for 0 .. 1;
+    $self->note($self->EIGHTH, $self->snare);
+    $self->note($self->EIGHTH, $self->kick) for 0 .. 1;
+    $self->note($self->EIGHTH, $self->snare);
+    $self->note($self->EIGHTH, $self->kick);
+},
 
     };
 }
@@ -273,7 +293,7 @@ MIDI::Simple::Drummer::Rock
 
 =head1 VERSION
 
-version 0.07
+version 0.0701
 
 =head1 DESCRIPTION
 
